/* ============================================================================
 * File Name: SerialPlot_P4_basic_01a
 *
 * Description:
 *   Basic xample showing use of SerialPlot component on PSoC4 for data output
 *   to real-time charting software (SerialPlot). Test data are generated 
 *   on WDT0 timer and sent to host computer for visualisation using UART.
 *
 * Credits:
 *   uses Serial PLOT v0.10.0 - freeware charting software by Yavuz Ozderya
 *   https://hasanyavuz.ozderya.net/?p=244
 *   https://bitbucket.org/hyOzd/serialplot   
 *
 * ============================================================================
 * PROVIDED AS-IS, NO WARRANTY OF ANY KIND, INCLUDING, BUT NOT LIMITED TO, THE
 * IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE.
 * FREE TO SHARE, USE AND MODIFY UNDER TERMS: CREATIVE COMMONS - SHARE ALIKE
 * ============================================================================
*/



#include "project.h"

#define BlinkLED(); {Pin_LED_Write(1); CyDelayUs(30); Pin_LED_Write(0);} // blink LED indicator



//============================================
// The interrupt handler for ISR Timer. 
//============================================
volatile CYBIT flag_ReportTimer = 0 ; //semaphore   
CY_ISR(isr_ReportTimer) 
{
    flag_ReportTimer = 1;
}


//===========================================
// Global variables
//===========================================


   
//===========================================
// Function prototypes
//===========================================


void Initialize()
{   
    CyGlobalIntEnable;              //enable global interrupts.
     
    isr_ReportTimer_StartEx(isr_ReportTimer);
    
    ClockN_1_Start();      // must go first
    //ClockN_1_SetPeriod(20); // can change period after ClockX is started
}


int main()
{  
    Initialize();  
    
    for(;;) //forever
    {
        
        if(flag_ReportTimer != 0)                   // monitor for Report Timer interrupt
        {
            flag_ReportTimer = 0;
            BlinkLED();                             // debug..

            ClockN_1_Trigger(); //trigger ClockX_1 
        }    
        
    }  
    
} // main








